@@ -1904,16 +1904,16 @@ Recivir (gchar *barcode, gchar *cantidad)
 
 gint
 SetModificacionesProveedor (gchar *rut, gchar *razon, gchar *direccion, gchar *comuna, 
-			    gchar *ciudad, gchar *fono, gchar *fax, gchar *web, gchar *contacto, 
-			    gchar *email, gchar *fonodirecto, gchar *giro)
+			    gchar *ciudad, gchar *fono, gchar *web, gchar *contacto, 
+			    gchar *email, gchar *giro)
 {
   PGresult *res;
   
   res = EjecutarSQL
     (g_strdup_printf ("UPDATE proveedores SET nombre='%s', direccion='%s', ciudad='%s', "
-		      "comuna='%s', telefono='%s', email='%s', web='%s', contacto='%s', giro='%s',"
-		      " fax='%s', fono_directo='%s' WHERE rut='%s'", razon, direccion, ciudad, 
-		      comuna, fono, email, web, contacto, giro, fax, fonodirecto, rut));
+		      "comuna='%s', telefono='%s', email='%s', web='%s', contacto='%s', giro='%s'"
+		      " WHERE rut='%s'", razon, direccion, ciudad, 
+		      comuna, fono, email, web, contacto, giro, rut));
 
   return 0;
 }
