@@ -367,7 +367,7 @@ ventas_stats_box (MainBox *module_box)
   gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (button_from), FALSE, FALSE, 3);
   gtk_widget_show (GTK_WIDGET (button_from));
 
-  gtk_window_set_focus (main_window, button_from);
+  gtk_window_set_focus (GTK_WINDOW (main_window), GTK_WIDGET (button_from));
 
   //  SetDate (NULL, (gpointer)button_from);
 
